<!-- SPDX-License-Identifier: MIT -->
# Contributing

This document explains how to contribute to `odxtools`. By
contributing you will implicitly agree that your contribution will be
made available under the same license as the relevant content of the
repository.

## Table of Contents

* [Communication](#communication)
* [Contributions](#contributions)

## Communication

We use GitHub to handle bug reports, feature requests, questions and
general discussions (via the "issues" and "discussions" features of
GitHub) as well as for managing code and documentation improvements
(via pull requests). Transparent, inclusive and open communication is
important to us; thus, all project-related communication should happen
exclusively on GitHub and using the English language.

In the context of project-related discussions, please respect our
[Code of Conduct](https://github.com/mercedes-benz/daimler-foss/blob/master/CODE_OF_CONDUCT.md).

## Contributions

### CLA

Before you can contribute, you will need to sign our Contributor
License Agreement (CLA). When you create your first pull request, you
will be requested by our CLA-assistant to sign this CLA.

### Pull requests

*All* changes to the contents of the `odxtools` repository are done via
GitHub's [standard workflow](https://guides.github.com/introduction/flow/)
--- in particular its pull request mechanism.

If you are new to contributing to projects on GitHub, our
[First Contributions](https://github.com/firstcontributions/first-contributions)
document might be a good starting point.
